macro_rules! assert_buffer_eq {
($actual_expr:expr, $expected_expr:expr) => { ... };
}Expand description
Assert that two buffers are equal by comparing their areas and content.
On panic, displays the areas or the content and a diff of the contents.