pub struct Frame<'a, B>where
B: Backend + 'a,{ /* private fields */ }Expand description
Represents a consistent terminal interface for rendering.
Implementations
Sourceimpl<'a, B> Frame<'a, B>where
B: Backend,
impl<'a, B> Frame<'a, B>where
B: Backend,
Sourcepub fn render_widget<W>(&mut self, widget: &mut W, area: Rect)where
W: Widget,
pub fn render_widget<W>(&mut self, widget: &mut W, area: Rect)where
W: Widget,
Render a Widget to the current buffer using Widget::render.
Examples
let mut block = Block::default();
let area = Rect::new(0, 0, 5, 5);
let mut frame = terminal.get_frame();
frame.render_widget(&mut block, area);pub fn current_buffer_mut(&mut self) -> &mut Buffer
Sourcepub fn set_cursor(&mut self, x: u16, y: u16)
pub fn set_cursor(&mut self, x: u16, y: u16)
After drawing this frame, make the cursor visible and put it at the specified (x, y) coordinates. If this method is not called, the cursor will be hidden.
Note that this will interfere with calls to Terminal::hide_cursor(),
Terminal::show_cursor(), and Terminal::set_cursor(). Pick one of the APIs and stick
with it.