widgets is a collection of types that implement Widget.
All widgets are implemented using the builder pattern and are consumable objects. They are not meant to be stored but used as commands to draw common figures in the UI.
The available widgets are:
Modules
Structs
- Axis
- An X or Y axis for the chart widget
- BarChart
- Display multiple bars in a single widgets
- Block
- Base widget to be used with all upper level ones. It may be used to display a box border around the widget and/or add a title.
- Borders
- Bitflags that can be composed to set the visible borders essentially on the block widget.
- Cell
- A
Cellcontains theTextto be displayed in aRowof aTable. - Chart
- A widget to plot one or more dataset in a cartesian coordinate system
- Clear
- A widget to clear/reset a certain area to allow overdrawing (e.g. for popups).
- Dataset
- A group of data points
- Gauge
- A widget to display a task progress.
- Line
Gauge - A compact widget to display a task progress over a single line.
- List
- A widget to display several items among which one can be selected (optional)
- List
Item - Paragraph
- A widget to display some text.
- Row
- Holds data to be displayed in a
Tablewidget. - Scrollbar
- Scrollbar widget for altui-core library.
- Sparkline
- Widget to render a sparkline over one or more lines.
- Table
- A widget to display data in formatted columns.
- Tabs
- A widget to display available tabs in a multiple panels context.
- Wrap
- Describes how to wrap text across lines.
Enums
- Border
Type - Graph
Type - Used to determine which style of graphing to use
- Scroll
Direction - An enum representing the direction of scrolling in a Scrollbar widget.
- Scrollbar
Orientation - Scrollbar Orientation
Constants
Traits
- Widget
- Base requirements for a Widget