Block

Struct Block 

pub struct Block<'a> { /* private fields */ }
Base widget to be used with all upper level ones. It may be used to display a box border around the widget and/or add a title.

Examples

Block::default()
    .title("Block")
    .borders(Borders::LEFT | Borders::RIGHT)
    .border_style(Style::default().fg(Color::White))
    .border_type(BorderType::Rounded)
    .style(Style::default().bg(Color::Black));

Implementations

Source

impl<'a> Block<'a>

pub fn styled_borders( borders: Borders, border_style: impl Into<Style>, ) -> Block<'a>

pub fn bordered(borders: Borders) -> Block<'a>

pub fn styled(style: Style) -> Block<'a>

pub fn title<T>(self, title: T) -> Block<'a>
where T: Into<Spans<'a>>,

pub fn title_alignment(self, alignment: Alignment) -> Block<'a>

pub fn border_style(self, style: Style) -> Block<'a>

pub fn style(self, style: Style) -> Block<'a>

pub fn borders(self, flag: Borders) -> Block<'a>

pub fn border_type(self, border_type: BorderType) -> Block<'a>

pub fn padding(self, padding: u16) -> Block<'a>

Set uniform padding on all sides

pub fn padding_all( self, left: u16, right: u16, top: u16, bottom: u16, ) -> Block<'a>

Set specific padding values

pub fn padding_horizontal(self, padding: u16) -> Block<'a>

Set horizontal padding

pub fn padding_vertical(self, padding: u16) -> Block<'a>

Set vertical padding

pub fn padding_left(self, padding: u16) -> Block<'a>

Set left padding only

pub fn padding_right(self, padding: u16) -> Block<'a>

Set right padding only

pub fn padding_top(self, padding: u16) -> Block<'a>

Set top padding only

pub fn padding_bottom(self, padding: u16) -> Block<'a>

Set bottom padding only

pub fn inner(&self, area: Rect) -> Rect

Compute the inner area of a block based on its border visibility rules and padding settings.