Paragraph

Struct Paragraph 

pub struct Paragraph<'a> { /* private fields */ }
A widget to display some text.

Examples

let text = vec![
    Spans::from(vec![
        Span::raw("First"),
        Span::styled("line",Style::default().add_modifier(Modifier::ITALIC)),
        Span::raw("."),
    ]),
    Spans::from(Span::styled("Second line", Style::default().fg(Color::Red))),
];
let mut paragraph = Paragraph::new(text);
paragraph.block(Block::default().title("Paragraph").borders(Borders::ALL));
paragraph.style(Style::default().fg(Color::White).bg(Color::Black));
paragraph.alignment(Alignment::Center);
paragraph.wrap(Wrap { trim: true });

Implementations

Source

impl<'a> Paragraph<'a>

pub fn new<T>(text: T) -> Paragraph<'a>
where T: Into<Text<'a>>,

pub fn text<T>(&mut self, text: T)
where T: Into<Text<'a>>,

pub fn block(&mut self, block: Block<'a>)

pub fn scrollbar(&mut self, scrollbar: Scrollbar<'a>)

Attach a scrollbar to the paragraph

Adds a scrollbar that visually indicates the current scroll position and allows users to understand the relative position within the content.

See Also
pub fn text_style(&mut self, style: Style)

pub fn style(&mut self, style: Style)

pub fn wrap(&mut self, wrap: Wrap)

pub fn margin(&mut self, margin: u16)

pub fn horizontal_margin(&mut self, horizontal: u16)

pub fn vertical_margin(&mut self, vertical: u16)

pub fn scroll(&mut self, offset: (u16, u16))

Sets Y and X axis offsets accordingly

Note

The scroll position will be automatically clamped during rendering to ensure it doesn’t exceed valid bounds:

  • Vertical scroll will be limited to max(0, content_height - viewport_height)
  • Horizontal scroll will be limited to max(0, content_width - viewport_width)

Content dimensions (content_height and content_width) are calculated during the first render after text changes. To get actual content dimensions:

  1. After setting new text, call render() at least once
  2. Then use Paragraph::content_height and Paragraph::content_width methods
pub fn alignment(&mut self, alignment: Alignment)

pub fn content_height(&self) -> Option<u16>

Returns Some(content height) if vertical scrollbar was set or None

pub fn content_width(&self) -> Option<u16>

Returns Some(content width) if horizontal scrollbar was set or None

This is the width of the longest line in the text.