pub struct Wrap {
pub trim: bool,
}Expand description
Describes how to wrap text across lines.
Examples
let bullet_points = Text::from(r#"Some indented points:
- First thing goes here and is long so that it wraps
- Here is another point that is long enough to wrap"#);
// With leading spaces trimmed (window width of 30 chars):
Paragraph::new(bullet_points.clone()).wrap(Wrap { trim: true });
// Some indented points:
// - First thing goes here and is
// long so that it wraps
// - Here is another point that
// is long enough to wrap
// But without trimming, indentation is preserved:
Paragraph::new(bullet_points).wrap(Wrap { trim: false });
// Some indented points:
// - First thing goes here
// and is long so that it wraps
// - Here is another point
// that is long enough to wrapFields
trim: boolShould leading whitespace be trimmed