style contains the primitives used to control how your user interface will look.
Structs
- Modifier
- Modifier changes the way a piece of text is displayed.
- Style
- Style let you control the main characteristics of the displayed elements.